@@ -1,7 +1,7 @@
 /*
  *  conf.h
  *
- *  Copyright (c) 2006-2016 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2006-2018 Pacman Development Team <pacman-dev@archlinux.org>
  *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -17,8 +17,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-#ifndef _PM_CONF_H
-#define _PM_CONF_H
+#ifndef PM_CONF_H
+#define PM_CONF_H
 
 #include <alpm.h>
 
@@ -37,9 +37,9 @@ typedef struct __colstr_t {
 typedef struct __config_repo_t {
 	char *name;
 	alpm_list_t *servers;
-	alpm_db_usage_t usage;
-	alpm_siglevel_t siglevel;
-	alpm_siglevel_t siglevel_mask;
+	int usage;
+	int siglevel;
+	int siglevel_mask;
 } config_repo_t;
 
 typedef struct __config_t {
@@ -55,6 +55,7 @@ typedef struct __config_t {
 	unsigned short checkspace;
 	unsigned short usesyslog;
 	unsigned short color;
+	unsigned short disable_dl_timeout;
 	double deltaratio;
 	char *arch;
 	char *print_format;
@@ -66,6 +67,7 @@ typedef struct __config_t {
 	char *dbpath;
 	char *logfile;
 	char *gpgdir;
+	char *sysroot;
 	alpm_list_t *hookdirs;
 	alpm_list_t *cachedirs;
 
@@ -95,14 +97,16 @@ typedef struct __config_t {
 	unsigned short group;
 	unsigned short noask;
 	unsigned int ask;
-	alpm_transflag_t flags;
-	alpm_siglevel_t siglevel;
-	alpm_siglevel_t localfilesiglevel;
-	alpm_siglevel_t remotefilesiglevel;
+	/* Bitfield of alpm_transflag_t */
+	int flags;
+	/* Bitfields of alpm_siglevel_t */
+	int siglevel;
+	int localfilesiglevel;
+	int remotefilesiglevel;
 
-	alpm_siglevel_t siglevel_mask;
-	alpm_siglevel_t localfilesiglevel_mask;
-	alpm_siglevel_t remotefilesiglevel_mask;
+	int siglevel_mask;
+	int localfilesiglevel_mask;
+	int remotefilesiglevel_mask;
 
 	/* conf file options */
 	/* I Love Candy! */
@@ -120,6 +124,7 @@ typedef struct __config_t {
 	alpm_list_t *assumeinstalled;
 	alpm_list_t *noupgrade;
 	alpm_list_t *noextract;
+	alpm_list_t *overwrite_files;
 	char *xfercommand;
 
 	/* our connection to libalpm */
@@ -169,6 +174,7 @@ enum {
 	OP_GPGDIR,
 	OP_DBONLY,
 	OP_FORCE,
+	OP_OVERWRITE_FILES,
 	OP_COLOR,
 	OP_DBPATH,
 	OP_CASCADE,
@@ -190,6 +196,7 @@ enum {
 	OP_PRINT,
 	OP_QUIET,
 	OP_ROOT,
+	OP_SYSROOT,
 	OP_RECURSIVE,
 	OP_SEARCH,
 	OP_REGEX,
@@ -201,7 +208,8 @@ enum {
 	OP_VERBOSE,
 	OP_DOWNLOADONLY,
 	OP_REFRESH,
-	OP_ASSUMEINSTALLED
+	OP_ASSUMEINSTALLED,
+	OP_DISABLEDLTIMEOUT
 };
 
 /* clean method */
@@ -234,6 +242,6 @@ void config_repo_free(config_repo_t *repo);
 
 int config_set_arch(const char *arch);
 int parseconfig(const char *file);
-#endif /* _PM_CONF_H */
-
-/* vim: set noet: */
+int parseconfigfile(const char *file);
+int setdefaults(config_t *c);
+#endif /* PM_CONF_H */
